def say_something():
    return 'Hi'